@@ -15,8 +15,8 @@ complete.tbl_ts <- function(data, ..., fill = list()) {
 
 spread_tsbl <- function(data, value, fill = NA, sep = "") {
   spread_val <- measured_vars(data)
-  str_val <- paste_comma(spread_val)
-  msg <- sprintf("Can't determine the `value`: %s?", str_val)
+  str_val <- paste_comma(surround(spread_val, "`"))
+  msg <- sprintf("Can't determine the `value`: %s.", str_val)
   if (quo_is_missing(value)) {
     if (is_false(has_length(spread_val, 1))) {
       abort(msg)
