@@ -1,19 +1,31 @@
 #' Sliding window calculation
 #'
-#' `slide()` is an S3 method to carry out rolling window calculation; `slider()`
-#' splits the input `x` to a list according to the window size.
+#' Rolling window with overlapping observations:
+#' * `slide()` always returns a vector of numerics
+#' * `slide_lst()` returns a list
+#' * `slide_dfr()` and `slide_dfc()` return data frame using row-binding and
+#' column-binding
+#' * `slider()` splits the input `x` to a list according to the window size.
 #'
-#' @param x A vector of numerics, or data frame.
+#' @param x A vector of numerics, or data frame. If a data frame, row-wise rolling
+#' window is performed.
 #' @param .f A function or one-sided formula using purrr-like syntax. If a 
 #' formula, it is converted to a function.
 #' @param ... Additional arguments passed on to `.f`.
 #' @param size An integer for window size.
 #' @param fill A single value or data frame to replace `NA`.
+#' @param .id If not `NULL` a variable with this name will be created giving 
+#' either the name or the index of the data frame, which is passed to 
+#' [dplyr::bind_rows].
 #'
 #' @rdname slide
 #' @export
 #' @seealso [tile] for tiling window without overlapping observations;
 #' [stretch] for expanding more observations
+#' @details The `slide()` function attempts to tackle more general problems using
+#' the purrr-like syntax. For some specialist functions like `mean` and `sum`, 
+#' you may like to check out for 
+#' [RcppRoll](https://CRAN.R-project.org/package=RcppRoll) for faster performance.
 #'
 #' @examples
 #' # sliding through a vector ----
@@ -28,66 +40,65 @@
 #' \dontrun{
 #' # takes a little longer for cran check
 #' # sliding a 2-day window for a data frame ----
-#' sx <- pedestrian %>% 
-#'   filter(Sensor == "Southern Cross Station", Date <= as.Date("2015-01-31"))
+#' jan <- pedestrian %>% 
+#'   filter(Date <= as.Date("2015-01-31")) %>% 
+#'   split(.$Sensor)
 #' # directly return a data frame of fitted values and residuals
-#' diag_sx <- sx %>%
-#'   slide(function(x) {
+#' diag_jan <- jan %>%
+#'   purrr::map_dfr(~ slide_dfr(., function(x) {
 #'     fit <- lm(Count ~ Time, data = x)
 #'     data.frame(fitted = fitted(fit), resid = residuals(fit))
-#'   }, size = 48, deframe = FALSE)
-#' diag_sx[48:57, ]
+#'   }, size = 48))
+#' diag_jan[48:57, ]
 #' # save lm models as additional columns
-#' lm_sx <- sx %>% 
-#'   mutate(lm = slide(., ~ lm(Count ~ Time, data = .), size = 48))
-#' lm_sx[48:57, ]
+#' lm_jan <- jan %>% 
+#'   purrr::map(~ mutate(., 
+#'     lm = slide_lst(., ~ lm(Count ~ Time, data = .), size = 48)
+#' ))
+#' lm_jan[[1]][48:57, ]
 #' }
-slide <- function(x, .f, ..., size = 1, fill) {
-  UseMethod("slide")
-}
-
-#' @rdname slide
-#' @details The `slide()` function attempts to tackle more general problems using
-#' the purrr-like syntax. For some specialist functions like `mean` and `sum`, 
-#' you may like to check out for 
-#' [RcppRoll](https://CRAN.R-project.org/package=RcppRoll) for faster performance.
 #' @export
-slide.default <- function(x, .f, ..., size = 1, fill = NA_real_) {
+slide <- function(x, .f, ..., size = 1, fill = NA_real_) {
   lst_x <- slider(x, size = size)
   c(rep_len(fill, size - 1), purrr::map_dbl(lst_x, .f, ...))
 }
 
 #' @rdname slide
-#' @param deframe TRUE a list is returned. FALSE returns a data frame.
 #' @export
-slide.data.frame <- function(
-  x, .f, ..., size = 1, fill = NA, deframe = TRUE
-) {
-  # currently not support grouped_df/ts
+slide_lst <- function(x, .f, ..., size = 1, fill = NA) {
   lst_x <- slider(x, size = size)
   result <- purrr::map(lst_x, .f, ...)
   if (is.na(fill)) {
     fill <- rep_len(fill, length(result[[1]]))
   }
-  out <- c(replicate(n = size - 1, fill, simplify = FALSE), result)
-  if (deframe) {
-    return(out)
-  } else if (is.null(names(out))) {
+  c(replicate(n = size - 1, fill, simplify = FALSE), result)
+}
+
+#' @rdname slide
+#' @export
+slide_dfr <- function(x, .f, ..., size = 1, fill = NA, .id = NULL) {
+  out <- slide_lst(x, .f = .f, ..., size = size, fill = fill)
+  if (is.null(names(out))) {
     return(as_tibble(do.call(rbind, out)))
-  } else {
-    dplyr::bind_rows(out)
   }
+  dplyr::bind_rows(out, .id = .id)
+}
+
+#' @rdname slide
+#' @export
+slide_dfc <- function(x, .f, ..., size = 1, fill = NA) {
+  out <- slide_lst(x, .f = .f, ..., size = size, fill = fill)
+  if (is.null(names(out))) {
+    return(as_tibble(do.call(cbind, out)))
+  }
+  dplyr::bind_cols(out)
 }
 
 #' @rdname slide
 #' @export
 slider <- function(x, size = 1) {
   bad_window_function(x, size)
-  if (is.data.frame(x)) {
-    len_x <- nrow(x)
-  } else {
-    len_x <- length(x)
-  }
+  len_x <- NROW(x)
   lst_idx <- seq_len(len_x - size + 1)
   if (is_atomic(x)) {
     return(purrr::map(lst_idx, ~ x[(.):(. + size - 1)]))
@@ -97,13 +108,14 @@ slider <- function(x, size = 1) {
 
 #' Tiling window calculation
 #'
-#' `tile()` is an S3 method to carry out tiling window calculation; `tiler()`
-#' splits the input `x` to a list according to the window size.
+#' Tiling window without overlapping observations:
+#' * `tile()` always returns a vector of numerics
+#' * `tile_lst()` returns a list
+#' * `tile_dfr()` and `tile_dfc()` return data frame using row-binding and
+#' column-binding
+#' * `tiler()` splits the input `x` to a list according to the window size.
 #'
-#' @param x A vector of numerics, or data frame.
 #' @inheritParams slide
-#' @param ... Additional arguments passed on to `.f`.
-#' @param size An integer for window size.
 #'
 #' @rdname tile
 #' @export
@@ -118,34 +130,41 @@ slider <- function(x, size = 1) {
 #' tiler(x, size = 3)
 #'
 #' # tiling over a 2-day window for hourly data ----
-#' sx <- pedestrian %>%
-#'   filter(Sensor == "Southern Cross Station", Date <= as.Date("2015-01-10"))
-#' sx %>% 
-#'   tile(~ quantile(.$Count), size = 48, deframe = FALSE)
+#' \dontrun{
+#' pedestrian %>% 
+#'   split(.$Sensor) %>% 
+#'   purrr::map_dfr(~ tile_dfr(., ~ quantile(.$Count), size = 48))
+#' }
 tile <- function(x, .f, ..., size = 1) {
-  UseMethod("tile")
-}
-
-#' @rdname tile
-#' @export
-tile.default <- function(x, .f, ..., size = 1) {
   lst_x <- tiler(x, size = size)
   purrr::map_dbl(lst_x, .f, ...)
 }
 
 #' @rdname tile
-#' @param deframe TRUE a list is returned. FALSE returns a data frame.
 #' @export
-tile.data.frame <- function(x, .f, ..., size = 1, deframe = TRUE) {
+tile_lst <- function(x, .f, ..., size = 1) {
   lst_x <- tiler(x, size = size)
-  out <- purrr::map(lst_x, .f, ...)
-  if (deframe) {
-    return(out)
-  } else if (is.null(names(out))) {
+  purrr::map(lst_x, .f, ...)
+}
+
+#' @rdname tile
+#' @export
+tile_dfr <- function(x, .f, ..., size = 1, .id = NULL) {
+  out <- tile_lst(x = x, .f = .f, ..., size = size)
+  if (is.null(names(out))) {
     return(as_tibble(do.call(rbind, out)))
-  } else {
-    dplyr::bind_rows(out)
   }
+  dplyr::bind_rows(out, .id = .id)
+}
+
+#' @rdname tile
+#' @export
+tile_dfc <- function(x, .f, ..., size = 1) {
+  out <- tile_lst(x = x, .f = .f, ..., size = size)
+  if (is.null(names(out))) {
+    return(as_tibble(do.call(cbind, out)))
+  }
+  dplyr::bind_cols(out)
 }
 
 #' @rdname tile
@@ -161,12 +180,14 @@ tiler <- function(x, size = 1) {
 
 #' Stretching window calculation
 #'
-#' `stretch()` is an S3 method to carry out expanding window calculation; 
-#' `stretcher()` splits the input `x` to a list according to the window size.
+#' Fixing an initial window and expanding more observations:
+#' * `stretch()` always returns a vector of numerics
+#' * `stretch_lst()` returns a list
+#' * `stretch_dfr()` and `stretch_dfc()` return data frame using row-binding and
+#' column-binding
+#' * `stretcher()` splits the input `x` to a list according to the window size.
 #'
-#' @param x A vector of numerics, or data frame.
 #' @inheritParams slide
-#' @param ... Additional arguments passed on to `.f`.
 #' @param size,init An integer for moving and initial window size.
 #'
 #' @rdname stretch
@@ -184,31 +205,37 @@ tiler <- function(x, size = 1) {
 #' sx <- pedestrian %>% 
 #'   filter(Sensor == "Southern Cross Station", Date <= as.Date("2015-01-10"))
 #' sx %>%
-#'   stretch(~ quantile(.$Count), init = 48, deframe = FALSE)
+#'   stretch_dfr(~ quantile(.$Count), init = 48)
 stretch <- function(x, .f, ..., size = 1, init = 1) {
-  UseMethod("stretch")
-}
-
-#' @rdname stretch
-#' @export
-stretch.default <- function(x, .f, ..., size = 1, init = 1) {
   lst_x <- stretcher(x, size = size, init = init)
   purrr::map_dbl(lst_x, .f, ...)
 }
 
 #' @rdname stretch
-#' @param deframe TRUE a list is returned. FALSE returns a data frame.
 #' @export
-stretch.data.frame <- function(x, .f, ..., size = 1, init = 1, deframe = TRUE) {
+stretch_lst <- function(x, .f, ..., size = 1, init = 1) {
   lst_x <- stretcher(x, size = size, init = init)
-  out <- purrr::map(lst_x, .f, ...)
-  if (deframe) {
-    return(out)
-  } else if (is.null(names(out))) {
+  purrr::map(lst_x, .f, ...)
+}
+
+#' @rdname stretch
+#' @export
+stretch_dfr <- function(x, .f, ..., size = 1, init = 1, .id = NULL) {
+  out <- stretch_lst(x, .f = .f, ..., size = size, init = init)
+  if (is.null(names(out))) {
     return(as_tibble(do.call(rbind, out)))
-  } else {
-    dplyr::bind_rows(out)
   }
+  dplyr::bind_rows(out, .id = .id)
+}
+
+#' @rdname stretch
+#' @export
+stretch_dfc <- function(x, .f, ..., size = 1, init = 1) {
+  out <- stretch_lst(x, .f = .f, ..., size = size, init = init)
+  if (is.null(names(out))) {
+    return(as_tibble(do.call(cbind, out)))
+  }
+  dplyr::bind_cols(out)
 }
 
 #' @rdname stretch
